@@ -1,4 +1,4 @@
-from dataclasses import field
+import copy
 from logging import Logger
 from pathlib import Path
 from typing import (
@@ -14,6 +14,7 @@ from typing import (
     Union,
 )
 
+from .field_utils import field
 from .flexyclasses import flexyclass
 from .initialize import Target
 from .logging import configure_logging
@@ -70,17 +71,37 @@ def make_flexy(cls_: Any) -> Any:
     return flexyclass(cls_)
 
 
+def fval(value: T, **kwargs) -> T:
+    """Shortcut for creating a Field with a default value.
+
+    Args:
+        value: value returned by default factory"""
+
+    return field(default=value, **kwargs)
+
+
+def fobj(object: T, **kwargs) -> T:
+    """Shortcut for creating a Field with a default_factory that returns
+    a specific object.
+
+    Args:
+        obj: object returned by default factory"""
+
+    def _factory_fn() -> T:
+        # make a copy so that the same object isn't returned
+        # (it's a factory, not a singleton!)
+        return copy.deepcopy(object)
+
+    return field(default_factory=_factory_fn, **kwargs)
+
+
 def fdict(**kwargs: Any) -> Dict[str, Any]:
     """Shortcut for creating a Field with a default_factory that returns
     a dictionary.
 
     Args:
         **kwargs: values for the dictionary returned by default factory"""
-
-    def _factory_fn() -> Dict[str, Any]:
-        return {**kwargs}
-
-    return field(default_factory=_factory_fn)
+    return fobj(kwargs)
 
 
 def flist(*args: Any) -> List[Any]:
@@ -89,11 +110,7 @@ def flist(*args: Any) -> List[Any]:
 
     Args:
         *args: values for the list returned by default factory"""
-
-    def _factory_fn() -> List[Any]:
-        return [*args]
-
-    return field(default_factory=_factory_fn)
+    return fobj(list(args))
 
 
 def debug_logger(*args: Any, **kwargs: Any) -> Logger:
